%global alt_name GPaste

Name:           gpaste
Version:        3.22.6
Release:        1%{?dist}
Summary:        Clipboard management system

Group:          User Interface/Desktops
License:        BSD
URL:            https://github.com/Keruspe/GPaste
Source0:        http://www.imagination-land.org/files/%{name}/%{name}-%{version}.tar.xz
# Fix build with autotools provided by EL
Patch0:         %{name}-3.22.4-el7_4.patch

BuildRequires:  appdata-tools
BuildRequires:  chrpath
BuildRequires:  desktop-file-utils
BuildRequires:  gcc
BuildRequires:  intltool
BuildRequires:  pkgconfig(appstream-glib)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gdk-x11-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-keybindings)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(mutter-clutter-1.0)
BuildRequires:  pkgconfig(vapigen)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description
GPaste is a clipboard management system.

This package provides the D-Bus service and the command-line client.


%package libs
Summary:        Library to manage the clipboard history
Group:          System Environment/Libraries

%description libs
GPaste is a clipboard management system.

This package contains the shared library used by GPaste.


%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.


%package applet
Summary:        Tray icon to manage GPaste
Group:          User Interface/Desktops
Requires:       %{name}-ui = %{version}-%{release}

%description applet
GPaste is a clipboard management system.

This package provides the GPaste status icon.


%package ui
Summary:        Graphical interface for GPaste
Group:          User Interface/Desktops
Requires:       %{name} = %{version}-%{release}
Requires:       control-center-filesystem

%description ui
GPaste is a clipboard management system.

This package provides a graphical interface for GPaste, as well as GNOME
integration (control center key bindings and search provider).


%package -n gnome-shell-extension-%{name}
Summary:        GNOME Shell extension for GPaste
Group:          User Interface/Desktops
Requires:       gnome-shell >= 3.22
Requires:       %{name}-ui = %{version}-%{release}
BuildArch:      noarch

%description -n gnome-shell-extension-%{name}
GPaste is a clipboard management system.

This package provides the GNOME Shell extension for GPaste.


%prep
%autosetup -p1


%build
NOCONFIGURE=1 ./autogen.sh
%configure \
  --disable-schemas-compile \
  --disable-silent-rules \
  --disable-unity \
  --enable-applet
%make_build


%install
%make_install DESTDIR=$RPM_BUILD_ROOT

rm $RPM_BUILD_ROOT%{_libdir}/*.la

# Remove Rpath
chrpath --delete \
    $RPM_BUILD_ROOT%{_bindir}/* \
    $RPM_BUILD_ROOT%{_libexecdir}/%{name}/*

%find_lang %{alt_name}


%check
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/org.gnome.GPaste.Applet.desktop
desktop-file-validate $RPM_BUILD_ROOT%{_datadir}/applications/org.gnome.GPaste.Ui.desktop
desktop-file-validate $RPM_BUILD_ROOT%{_sysconfdir}/xdg/autostart/org.gnome.GPaste.Applet.desktop


%post
%systemd_user_post org.gnome.GPaste.service


%post libs -p /sbin/ldconfig


%post applet
%systemd_user_post org.gnome.GPaste.Applet.service


%post ui
%systemd_user_post org.gnome.GPaste.Ui.service


%preun
%systemd_user_preun org.gnome.GPaste.service


%preun applet
%systemd_user_preun org.gnome.GPaste.Applet.service


%preun ui
%systemd_user_preun org.gnome.GPaste.Ui.service


%postun
%systemd_user_postun_with_restart org.gnome.GPaste.service
if [ $1 -eq 0 ]; then
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :
fi


%postun libs -p /sbin/ldconfig


%postun applet
%systemd_user_postun_with_restart org.gnome.GPaste.Applet.service


%postun ui
%systemd_user_postun_with_restart org.gnome.GPaste.Ui.service


%posttrans
/usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &>/dev/null || :


%files
%doc AUTHORS NEWS README.md THANKS
%license COPYING
%{_bindir}/%{name}-client
%dir %{_libexecdir}/%{name}/
%{_libexecdir}/%{name}/gpaste-daemon
%{_datadir}/dbus-1/services/org.gnome.GPaste.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/bash-completion/
%{_datadir}/zsh/
%{_userunitdir}/org.gnome.GPaste.service
%{_mandir}/man1/*.1.*


%files libs -f %{alt_name}.lang
%{_libdir}/girepository-1.0/%{alt_name}-1.0.typelib
%{_libdir}/*.so.*


%files devel
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/*
%{_includedir}/%{name}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%files applet
%{_libexecdir}/%{name}/%{name}-applet
%{_datadir}/appdata/org.gnome.GPaste.Applet.appdata.xml
%{_datadir}/applications/org.gnome.GPaste.Applet.desktop
%{_datadir}/dbus-1/services/org.gnome.GPaste.Applet.service
%{_sysconfdir}/xdg/autostart/org.gnome.GPaste.Applet.desktop
%{_userunitdir}/org.gnome.GPaste.Applet.service


%files ui
%{_libexecdir}/%{name}/gpaste-ui
%{_datadir}/applications/org.gnome.GPaste.Ui.desktop
%{_datadir}/appdata/org.gnome.GPaste.Ui.appdata.xml
%{_datadir}/dbus-1/services/org.gnome.GPaste.Ui.service
%{_datadir}/gnome-control-center/keybindings/*.xml
%{_datadir}/gnome-shell/search-providers/*.ini
%{_userunitdir}/org.gnome.GPaste.Ui.service


%files -n gnome-shell-extension-%{name}
%{_datadir}/gnome-shell/extensions/GPaste@gnome-shell-extensions.gnome.org/


%changelog
* Thu Mar 08 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.22.6-1
- Update to 3.22.6

* Mon Oct 16 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.22.4-2
- Fix build with EL 7.4

* Thu Oct 12 2017 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.22.4-1
- Update to 3.22.4

* Fri Jan 15 2016 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.14.4.1-1
- Update to 3.14.4.1

* Sat Mar 22 2014 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.3.1-1
- Update to 3.3.1

* Sun Feb 23 2014 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.3-1
- Update to 3.3

* Tue Oct 22 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.2.2-1
- Update to 3.2.2

* Sat Oct 19 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.2.1-1
- Update to 3.2.1

* Tue Sep 24 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.1-1
- Update to 3.1

* Sun Jun 02 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.2-1
- Update to 3.0.2

* Fri May 10 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-2
- Fix bash completion

* Fri May 10 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 3.0.1-1
- Update to 3.0.1

* Sun Apr 07 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-3.20130331gitc93a4ac
- Add missing BuildRequires on pkgconfig(gnome-keybindings)

* Sun Apr 07 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-2.20130331gitc93a4ac
- Update to a newer snapshot
- Move bash completion script to /usr/share/bash-completion/completion/

* Mon Jan 28 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.2-1
- Update to 2.99.2
- Drop patch gpaste-2.99.1-fix_gpaste-settings

* Thu Jan 17 2013 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.99.1-1
- Update to 2.99.1

* Sun Dec 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.9.1-1
- Update to 2.9.1
- Drop patch gpaste-2.9-gir.patch, fixed upstream

* Sun Sep 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.9-1
- Update to 2.9
- Enable GNOME fallback applet

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat May 19 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.8.1-1
- Update to 2.8.1

* Thu May 03 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.8-1
- Update to 2.8

* Sun Apr 08 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.5-2
- Fix Group and Requires tags in subpackages

* Fri Mar 30 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.5-1
- Update to 2.5

* Sat Jan 07 2012 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.2.1-1
- Update to 2.2.1

* Fri Dec 09 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.1-1
- Update to 2.1

* Tue Nov 29 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 2.0-1
- Update to 2.0

* Sun Sep 25 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.6-1
- Update to 1.6
- Remove no longer needed gpaste-1.5-DOS.patch patch

* Wed Sep 14 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.5-1
- Update to 1.5
- Remove gpaste-1.3-remove_applet_refs.patch patch (there is no more reference
  to the GNOME 2 applet in documentation and completion files)
- Add gpaste-1.5-DSO.patch to fix DSO linking

* Sat Sep 03 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.3-1
- Update to 1.3

* Sun Jul 10 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 1.2-1
- Update to 1.2

* Sat Jun 25 2011 Mohamed El Morabity <melmorabity@fedoraproject.org> - 0.99-1.17dd47git
- Initial RPM release
